@@ -34,9 +34,6 @@ G_BEGIN_DECLS
 
 #define GOA_OAUTH2_ACCESS_DENIED "access_denied"
 
-#define GOA_SETTINGS_SCHEMA "org.gnome.online-accounts"
-#define GOA_SETTINGS_WHITELISTED_PROVIDERS "whitelisted-providers"
-
 typedef gpointer (*GoaPeekInterfaceFunc)   (GoaObject *);
 
 gboolean         goa_utils_check_duplicate (GoaClient              *client,
